@@ -346,11 +346,15 @@
                         undef,
                     'Games::Axmud::Strip::GaugeBox',
                         undef,
+                    'Games::Axmud::Strip::SearchBox',
+                        undef,
                     'Games::Axmud::Strip::Entry',
                         {
                             'wipe_flag'     => TRUE,
+                            'add_flag'      => TRUE,
                             'console_flag'  => TRUE,
                             'input_flag'    => TRUE,
+                            'search_flag'   => TRUE,
                             'cancel_flag'   => TRUE,
                             'switch_flag'   => TRUE,
                             'scroll_flag'   => TRUE,
